.. role:: draft
.. role:: ready
.. role:: closed

********************
Administration panel
********************

Chat manager
============

Chat manager is a page with chats list. Such table does not contain message information. It looks like:

.. list-table::
  
    * - **Chat token**
      - **Created**
      - **Status**

    * - 5******2708
      - 10-May-2015, 18:29:48
      - :ready:`ready`

    * - 5******d8c8
      - 18-Apr-2015, 10:01:11
      - :draft:`draft`

    * - 5******d8c7
      - 18-Apr-2015, 09:01:11
      - :closed:`closed`

Clear chat
==========

For clear chats push the button under chat's table. [#f1]_


.. rubric:: Footnotes

.. [#f1] Read :ref:`Chat_termination` for details 
